# frozen_string_literal: true

#
# Cookbook:: cronic
# Library:: provider/cronic
#
# Copyright:: 2013, Tyler Technologies
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

require 'chef/provider/cron'
require 'chef/resource/cookbook_file'

class Chef
  class Provider
    # Take the core cron resource and add creation of the cronic script as a
    # part of the :create action.
    class Cronic < Cron
      provides :cronic do |node|
        !%w[debian rhel fedora amazon].include?(node['platform_family'])
      end

      def action_create
        declare_resource(:cookbook_file, '/usr/local/sbin/cronic') do
          cookbook 'cronic'
          owner 'root'
          group 'root'
          mode '0755'
        end.run_action(:create)

        super()
      end
    end
  end
end
